@@ -28,7 +28,6 @@
 #include <errno.h>
 #include <stdio.h>
 #include <fcntl.h>
-#include <poll.h>
 
 #include <glib.h>
 #include <glib/gstdio.h>
@@ -43,22 +42,40 @@
 
 /**
  * SECTION:gunixinputstream
- * @short_description: Streaming input operations for Unix file descriptors
+ * @short_description: Streaming input operations for UNIX file descriptors
  * @include: gio/gunixinputstream.h
  * @see_also: #GInputStream
  *
  * #GUnixInputStream implements #GInputStream for reading from a
- * unix file descriptor, including asynchronous operations. The file
+ * UNIX file descriptor, including asynchronous operations. The file
  * descriptor must be selectable, so it doesn't work with opened files.
- **/
+ *
+ * Note that <filename>&lt;gio/gunixinputstream.h&gt;</filename> belongs 
+ * to the UNIX-specific GIO interfaces, thus you have to use the 
+ * <filename>gio-unix-2.0.pc</filename> pkg-config file when using it.
+ */
+
+enum {
+  PROP_0,
+  PROP_FD,
+  PROP_CLOSE_FD
+};
 
 G_DEFINE_TYPE (GUnixInputStream, g_unix_input_stream, G_TYPE_INPUT_STREAM);
 
 struct _GUnixInputStreamPrivate {
   int fd;
-  gboolean close_fd_at_close;
+  gboolean close_fd;
 };
 
+static void     g_unix_input_stream_set_property (GObject              *object,
+						  guint                 prop_id,
+						  const GValue         *value,
+						  GParamSpec           *pspec);
+static void     g_unix_input_stream_get_property (GObject              *object,
+						  guint                 prop_id,
+						  GValue               *value,
+						  GParamSpec           *pspec);
 static gssize   g_unix_input_stream_read         (GInputStream         *stream,
 						  void                 *buffer,
 						  gsize                 count,
@@ -113,7 +130,9 @@ g_unix_input_stream_class_init (GUnixInputStreamClass *klass)
   GInputStreamClass *stream_class = G_INPUT_STREAM_CLASS (klass);
   
   g_type_class_add_private (klass, sizeof (GUnixInputStreamPrivate));
-  
+
+  gobject_class->get_property = g_unix_input_stream_get_property;
+  gobject_class->set_property = g_unix_input_stream_set_property;
   gobject_class->finalize = g_unix_input_stream_finalize;
 
   stream_class->read_fn = g_unix_input_stream_read;
@@ -128,6 +147,83 @@ g_unix_input_stream_class_init (GUnixInputStreamClass *klass)
     }
   stream_class->close_async = g_unix_input_stream_close_async;
   stream_class->close_finish = g_unix_input_stream_close_finish;
+
+  /**
+   * GUnixInputStream:fd:
+   *
+   * The file descriptor that the stream reads from.
+   *
+   * Since: 2.20
+   */
+  g_object_class_install_property (gobject_class,
+				   PROP_FD,
+				   g_param_spec_int ("fd",
+						     _("File descriptor"),
+						     _("The file descriptor to read from"),
+						     G_MININT, G_MAXINT, -1,
+						     G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT_ONLY | G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB));
+
+  /**
+   * GUnixInputStream:close-fd:
+   *
+   * Whether to close the file descriptor when the stream is closed.
+   *
+   * Since: 2.20
+   */
+  g_object_class_install_property (gobject_class,
+				   PROP_CLOSE_FD,
+				   g_param_spec_boolean ("close-fd",
+							 _("Close file descriptor"),
+							 _("Whether to close the file descriptor when the stream is closed"),
+							 TRUE,
+							 G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB));
+}
+
+static void
+g_unix_input_stream_set_property (GObject         *object,
+				  guint            prop_id,
+				  const GValue    *value,
+				  GParamSpec      *pspec)
+{
+  GUnixInputStream *unix_stream;
+  
+  unix_stream = G_UNIX_INPUT_STREAM (object);
+
+  switch (prop_id)
+    {
+    case PROP_FD:
+      unix_stream->priv->fd = g_value_get_int (value);
+      break;
+    case PROP_CLOSE_FD:
+      unix_stream->priv->close_fd = g_value_get_boolean (value);
+      break;
+    default:
+      G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
+      break;
+    }
+}
+
+static void
+g_unix_input_stream_get_property (GObject    *object,
+				  guint       prop_id,
+				  GValue     *value,
+				  GParamSpec *pspec)
+{
+  GUnixInputStream *unix_stream;
+
+  unix_stream = G_UNIX_INPUT_STREAM (object);
+
+  switch (prop_id)
+    {
+    case PROP_FD:
+      g_value_set_int (value, unix_stream->priv->fd);
+      break;
+    case PROP_CLOSE_FD:
+      g_value_set_boolean (value, unix_stream->priv->close_fd);
+      break;
+    default:
+      G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
+    }
 }
 
 static void
@@ -136,34 +232,100 @@ g_unix_input_stream_init (GUnixInputStream *unix_stream)
   unix_stream->priv = G_TYPE_INSTANCE_GET_PRIVATE (unix_stream,
 						   G_TYPE_UNIX_INPUT_STREAM,
 						   GUnixInputStreamPrivate);
+
+  unix_stream->priv->fd = -1;
+  unix_stream->priv->close_fd = TRUE;
 }
 
 /**
  * g_unix_input_stream_new:
- * @fd: unix file descriptor.
- * @close_fd_at_close: a #gboolean.
+ * @fd: a UNIX file descriptor
+ * @close_fd: %TRUE to close the file descriptor when done
  * 
- * Creates a new #GUnixInputStream for the given @fd. If @close_fd_at_close
- * is %TRUE, the file descriptor will be closed when the stream is closed.
+ * Creates a new #GUnixInputStream for the given @fd. 
+ *
+ * If @close_fd is %TRUE, the file descriptor will be closed 
+ * when the stream is closed.
  * 
- * Returns: a #GUnixInputStream. 
+ * Returns: a new #GUnixInputStream
  **/
 GInputStream *
-g_unix_input_stream_new (int      fd,
-			 gboolean close_fd_at_close)
+g_unix_input_stream_new (gint     fd,
+			 gboolean close_fd)
 {
   GUnixInputStream *stream;
 
   g_return_val_if_fail (fd != -1, NULL);
 
-  stream = g_object_new (G_TYPE_UNIX_INPUT_STREAM, NULL);
+  stream = g_object_new (G_TYPE_UNIX_INPUT_STREAM,
+			 "fd", fd,
+			 "close-fd", close_fd,
+			 NULL);
 
-  stream->priv->fd = fd;
-  stream->priv->close_fd_at_close = close_fd_at_close;
-  
   return G_INPUT_STREAM (stream);
 }
 
+/**
+ * g_unix_input_stream_set_close_fd:
+ * @stream: a #GUnixInputStream
+ * @close_fd: %TRUE to close the file descriptor when done
+ *
+ * Sets whether the file descriptor of @stream shall be closed
+ * when the stream is closed.
+ *
+ * Since: 2.20
+ */
+void
+g_unix_input_stream_set_close_fd (GUnixInputStream *stream,
+				  gboolean          close_fd)
+{
+  g_return_if_fail (G_IS_UNIX_INPUT_STREAM (stream));
+
+  close_fd = close_fd != FALSE;
+  if (stream->priv->close_fd != close_fd)
+    {
+      stream->priv->close_fd = close_fd;
+      g_object_notify (G_OBJECT (stream), "close-fd");
+    }
+}
+
+/**
+ * g_unix_input_stream_get_close_fd:
+ * @stream: a #GUnixInputStream
+ *
+ * Returns whether the file descriptor of @stream will be
+ * closed when the stream is closed.
+ *
+ * Return value: %TRUE if the file descriptor is closed when done
+ *
+ * Since: 2.20
+ */
+gboolean
+g_unix_input_stream_get_close_fd (GUnixInputStream *stream)
+{
+  g_return_val_if_fail (G_IS_UNIX_INPUT_STREAM (stream), FALSE);
+
+  return stream->priv->close_fd;
+}
+
+/**
+ * g_unix_input_stream_get_fd:
+ * @stream: a #GUnixInputStream
+ *
+ * Return the UNIX file descriptor that the stream reads from.
+ *
+ * Return value: The file descriptor of @stream
+ *
+ * Since: 2.20
+ */
+gint
+g_unix_input_stream_get_fd (GUnixInputStream *stream)
+{
+  g_return_val_if_fail (G_IS_UNIX_INPUT_STREAM (stream), -1);
+  
+  return stream->priv->fd;
+}
+
 static gssize
 g_unix_input_stream_read (GInputStream  *stream,
 			  void          *buffer,
@@ -173,23 +335,18 @@ g_unix_input_stream_read (GInputStream  *stream,
 {
   GUnixInputStream *unix_stream;
   gssize res;
-  struct pollfd poll_fds[2];
+  GPollFD poll_fds[2];
   int poll_ret;
-  int cancel_fd;
 
   unix_stream = G_UNIX_INPUT_STREAM (stream);
 
-  cancel_fd = g_cancellable_get_fd (cancellable);
-  if (cancel_fd != -1)
+  if (cancellable)
     {
+      poll_fds[0].fd = unix_stream->priv->fd;
+      poll_fds[0].events = G_IO_IN;
+      g_cancellable_make_pollfd (cancellable, &poll_fds[1]);
       do
-	{
-	  poll_fds[0].events = POLLIN;
-	  poll_fds[0].fd = unix_stream->priv->fd;
-	  poll_fds[1].events = POLLIN;
-	  poll_fds[1].fd = cancel_fd;
-	  poll_ret = poll (poll_fds, 2, -1);
-	}
+	poll_ret = g_poll (poll_fds, 2, -1);
       while (poll_ret == -1 && errno == EINTR);
       
       if (poll_ret == -1)
@@ -207,7 +364,7 @@ g_unix_input_stream_read (GInputStream  *stream,
   while (1)
     {
       if (g_cancellable_set_error_if_cancelled (cancellable, error))
-	break;
+	return -1;
       res = read (unix_stream->priv->fd, buffer, count);
       if (res == -1)
 	{
@@ -238,7 +395,7 @@ g_unix_input_stream_close (GInputStream  *stream,
 
   unix_stream = G_UNIX_INPUT_STREAM (stream);
 
-  if (!unix_stream->priv->close_fd_at_close)
+  if (!unix_stream->priv->close_fd)
     return TRUE;
   
   while (1)
@@ -346,7 +503,7 @@ g_unix_input_stream_read_async (GInputStream        *stream,
   data->stream = unix_stream;
 
   source = _g_fd_source_new (unix_stream->priv->fd,
-			     POLLIN,
+			     G_IO_IN,
 			     cancellable);
   
   g_source_set_callback (source, (GSourceFunc)read_async_cb, data, g_free);
@@ -418,7 +575,7 @@ close_async_cb (CloseAsyncData *data)
 
   unix_stream = G_UNIX_INPUT_STREAM (data->stream);
 
-  if (!unix_stream->priv->close_fd_at_close)
+  if (!unix_stream->priv->close_fd)
     {
       result = TRUE;
       goto out;
