@@ -204,7 +204,7 @@ g_once_init_enter_impl (volatile gsize *value_location)
 {
   gboolean need_init = FALSE;
   g_mutex_lock (g_once_mutex);
-  if (g_atomic_pointer_get ((void**) value_location) == NULL)
+  if (g_atomic_pointer_get (value_location) == NULL)
     {
       if (!g_slist_find (g_once_init_list, (void*) value_location))
         {
@@ -224,11 +224,11 @@ void
 g_once_init_leave (volatile gsize *value_location,
                    gsize           initialization_value)
 {
-  g_return_if_fail (g_atomic_pointer_get ((void**) value_location) == NULL);
+  g_return_if_fail (g_atomic_pointer_get (value_location) == NULL);
   g_return_if_fail (initialization_value != 0);
   g_return_if_fail (g_once_init_list != NULL);
 
-  g_atomic_pointer_set ((void**) value_location, (void*) initialization_value);
+  g_atomic_pointer_set (value_location, (void*) initialization_value);
   g_mutex_lock (g_once_mutex);
   g_once_init_list = g_slist_remove (g_once_init_list, (void*) value_location);
   g_cond_broadcast (g_once_cond);
@@ -256,7 +256,7 @@ g_static_mutex_get_mutex_impl (GMutex** mutex)
   g_mutex_lock (g_once_mutex);
 
   if (!(*mutex))
-    g_atomic_pointer_set ((void**) mutex, g_mutex_new());
+    g_atomic_pointer_set (mutex, g_mutex_new());
 
   g_mutex_unlock (g_once_mutex);
 
@@ -497,10 +497,10 @@ g_static_private_set (GStaticPrivate *private_key,
 void
 g_static_private_free (GStaticPrivate *private_key)
 {
-  guint index = private_key->index;
+  guint idx = private_key->index;
   GRealThread *thread;
 
-  if (!index)
+  if (!idx)
     return;
 
   private_key->index = 0;
@@ -513,27 +513,27 @@ g_static_private_free (GStaticPrivate *private_key)
       GArray *array = thread->private_data;
       thread = thread->next;
 
-      if (array && index <= array->len)
+      if (array && idx <= array->len)
 	{
 	  GStaticPrivateNode *node = &g_array_index (array,
 						     GStaticPrivateNode,
-						     index - 1);
+						     idx - 1);
 	  gpointer ddata = node->data;
 	  GDestroyNotify ddestroy = node->destroy;
 
 	  node->data = NULL;
 	  node->destroy = NULL;
 
-	  if (ddestroy)
-	    {
-	      G_UNLOCK (g_thread);
-	      ddestroy (ddata);
-	      G_LOCK (g_thread);
-	      }
+          if (ddestroy)
+            {
+              G_UNLOCK (g_thread);
+              ddestroy (ddata);
+              G_LOCK (g_thread);
+            }
 	}
     }
   g_thread_free_indeces = g_slist_prepend (g_thread_free_indeces,
-					   GUINT_TO_POINTER (index));
+					   GUINT_TO_POINTER (idx));
   G_UNLOCK (g_thread);
 }
 
@@ -638,13 +638,13 @@ g_thread_create_proxy (gpointer data)
 }
 
 GThread*
-g_thread_create_full (GThreadFunc 		 func,
-		      gpointer 		 data,
-		      gulong 		 stack_size,
-		      gboolean 		 joinable,
-		      gboolean 		 bound,
-		      GThreadPriority 	 priority,
-		      GError                **error)
+g_thread_create_full (GThreadFunc       func,
+		      gpointer          data,
+		      gulong            stack_size,
+		      gboolean          joinable,
+		      gboolean 	        bound,
+		      GThreadPriority   priority,
+		      GError          **error)
 {
   GRealThread* result;
   GError *local_error = NULL;
@@ -974,5 +974,18 @@ g_thread_foreach (GFunc    thread_func,
     }
 }
 
+/**
+ * g_thread_get_initialized
+ *
+ * Indicates if g_thread_init() has been called.
+ *
+ * Since: 2.20
+ */
+gboolean
+g_thread_get_initialized ()
+{
+  return g_thread_supported ();
+}
+
 #define __G_THREAD_C__
 #include "galiasdef.c"
