@@ -120,10 +120,6 @@
 #include <langinfo.h>
 #endif
 
-#ifdef HAVE_BIND_TEXTDOMAIN_CODESET
-#include <libintl.h>
-#endif
-
 const guint glib_major_version = GLIB_MAJOR_VERSION;
 const guint glib_minor_version = GLIB_MINOR_VERSION;
 const guint glib_micro_version = GLIB_MICRO_VERSION;
@@ -150,16 +146,40 @@ DllMain (HINSTANCE hinstDLL,
 #endif
 
 gchar *
-_glib_get_installation_directory (void)
+_glib_get_dll_directory (void)
 {
+  gchar *retval;
+  gchar *p;
+  wchar_t wc_fn[MAX_PATH];
+
 #ifdef DLL_EXPORT
   if (glib_dll == NULL)
     return NULL;
 #endif
-  /* In a static build of GLib just use the application's .exe file's
-   * installation directory...
+
+  /* This code is different from that in
+   * g_win32_get_package_installation_directory_of_module() in that
+   * here we return the actual folder where the GLib DLL is. We don't
+   * do the check for it being in a "bin" or "lib" subfolder and then
+   * returning the parent of that.
+   *
+   * In a statically built GLib, glib_dll will be NULL and we will
+   * thus look up the application's .exe file's location.
    */
-  return g_win32_get_package_installation_directory_of_module (glib_dll);
+  if (!GetModuleFileNameW (glib_dll, wc_fn, MAX_PATH))
+    return NULL;
+
+  retval = g_utf16_to_utf8 (wc_fn, -1, NULL, NULL, NULL);
+
+  p = strrchr (retval, G_DIR_SEPARATOR);
+  if (p == NULL)
+    {
+      /* Wtf? */
+      return NULL;
+    }
+  *p = '\0';
+
+  return retval;
 }
 
 #endif
@@ -595,7 +615,7 @@ debug_key_matches (const gchar *key,
 /**
  * g_parse_debug_string:
  * @string: a list of debug options separated by colons, spaces, or
- * commas; or the string "all" to set all flags, or %NULL.
+ * commas, or %NULL.
  * @keys: pointer to an array of #GDebugKey which associate 
  *     strings with bit flags.
  * @nkeys: the number of #GDebugKey<!-- -->s in the array.
@@ -605,6 +625,10 @@ debug_key_matches (const gchar *key,
  * within GDK and GTK+ to parse the debug options passed on the
  * command line or through environment variables.
  *
+ * If @string is equal to "all", all flags are set.  If @string
+ * is equal to "help", all the available keys in @keys are printed
+ * out to standard error.
+ *
  * Returns: the combined set of bit flags.
  */
 guint	     
@@ -628,6 +652,14 @@ g_parse_debug_string  (const gchar     *string,
       for (i=0; i<nkeys; i++)
 	result |= keys[i].value;
     }
+  else if (!g_ascii_strcasecmp (string, "help"))
+    {
+      /* using stdio directly for the reason stated above */
+      fprintf (stderr, "Supported debug values: ");
+      for (i=0; i<nkeys; i++)
+	fprintf (stderr, " %s", keys[i].key);
+      fprintf (stderr, "\n");
+    }
   else
     {
       const gchar *p = string;
@@ -1811,13 +1843,13 @@ g_get_real_name (void)
  * </simplelist>
  * Since applications are in general <emphasis>not</emphasis> written 
  * to deal with these situations it was considered better to make 
- * g_get_homedir() not pay attention to <envar>HOME</envar> and to 
+ * g_get_home_dir() not pay attention to <envar>HOME</envar> and to 
  * return the real home directory for the user. If applications
  * want to pay attention to <envar>HOME</envar>, they can do:
  * |[
  *  const char *homedir = g_getenv ("HOME");
  *   if (!homedir)
- *      homedir = g_get_homedir (<!-- -->);
+ *      homedir = g_get_home_dir (<!-- -->);
  * ]|
  *
  * Returns: the current user's home directory
